@@ -53,31 +53,25 @@ def reference_to_string(bookname, chapter, verse=None,
 
     book = get_book(bn)
 
-    # if start and end chapters are the same
-    if c == ec:
-
-        if len(book[3]) == 1: # single chapter book
-            # If start and end verses are the same
-            if v == ev:
-                return '{0} {1}'.format(bn, v)
-            else:
-                return '{0} {1}-{2}'.format(bn, v, ev)
-        else: # multichapter book
-            # If the start verse is one and the end verse is the last verse in
-            # the chapter
-            if v == 1 and ev == book[3][c-1]:
+    if c == ec and len(book[3]) == 1: # single chapter book
+        if v == ev: # single verse
+            return '{0} {1}'.format(bn, v)
+        else: # multiple verses
+            return '{0} {1}-{2}'.format(bn, v, ev)
+    else: # multichapter book
+        if c == ec: # same start and end chapters
+            if v == 1 and ev == book[3][c-1]: # full chapter
                 return '{0} {1}'.format(bn, c)
-            # If start and end verses are the same
-            elif v == ev:
+            elif v == ev: # single verse
                 return '{0} {1}:{2}'.format(bn, c, v)
-            else:
+            else: # multiple verses
                 return '{0} {1}:{2}-{3}'.format(
                     bn, c, v, ev)
-    else: 
-        if v == 1 and ev == book[3][ec-1]:
-            return '{0} {1}-{2}'.format(bn, c, ec)
-        else: # multi-chapter, verse reference
-            return '{0} {1}:{2}-{3}:{4}'.format(bn, c, v, ec, ev)
+        else: # multiple chapters
+            if v == 1 and ev == book[3][ec-1]: # multichapter ref
+                return '{0} {1}-{2}'.format(bn, c, ec)
+            else: # multi-chapter, multi-verse ref
+                return '{0} {1}:{2}-{3}:{4}'.format(bn, c, v, ec, ev)
 
 def normalize_reference(bookname, chapter, verse=None,
                                   end_chapter=None, end_verse=None):
